#[non_exhaustive]pub struct UpdateDataCatalogInput {
pub name: Option<String>,
pub type: Option<DataCatalogType>,
pub description: Option<String>,
pub parameters: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the data catalog to update. The catalog name must be unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.
type: Option<DataCatalogType>Specifies the type of data catalog to update. Specify LAMBDA for a federated catalog, HIVE for an external hive metastore, or GLUE for an Glue Data Catalog.
description: Option<String>New or modified text that describes the data catalog.
parameters: Option<HashMap<String, String>>Specifies the Lambda function or functions to use for updating the data catalog. This is a mapping whose values depend on the catalog type.
-
For the
HIVEdata catalog type, use the following syntax. Themetadata-functionparameter is required.The sdk-versionparameter is optional and defaults to the currently supported version.metadata-function=lambda_arn, sdk-version=version_number -
For the
LAMBDAdata catalog type, use one of the following sets of required parameters, but not both.-
If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.
metadata-function=lambda_arn, record-function=lambda_arn -
If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.
function=lambda_arn
-
Implementations
Sourceimpl UpdateDataCatalogInput
impl UpdateDataCatalogInput
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
The name of the data catalog to update. The catalog name must be unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.
Sourcepub fn type(&self) -> Option<&DataCatalogType>
pub fn type(&self) -> Option<&DataCatalogType>
Specifies the type of data catalog to update. Specify LAMBDA for a federated catalog, HIVE for an external hive metastore, or GLUE for an Glue Data Catalog.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
New or modified text that describes the data catalog.
Sourcepub fn parameters(&self) -> Option<&HashMap<String, String>>
pub fn parameters(&self) -> Option<&HashMap<String, String>>
Specifies the Lambda function or functions to use for updating the data catalog. This is a mapping whose values depend on the catalog type.
-
For the
HIVEdata catalog type, use the following syntax. Themetadata-functionparameter is required.The sdk-versionparameter is optional and defaults to the currently supported version.metadata-function=lambda_arn, sdk-version=version_number -
For the
LAMBDAdata catalog type, use one of the following sets of required parameters, but not both.-
If you have one Lambda function that processes metadata and another for reading the actual data, use the following syntax. Both parameters are required.
metadata-function=lambda_arn, record-function=lambda_arn -
If you have a composite Lambda function that processes both metadata and data, use the following syntax to specify your Lambda function.
function=lambda_arn
-
Sourceimpl UpdateDataCatalogInput
impl UpdateDataCatalogInput
Sourcepub fn builder() -> UpdateDataCatalogInputBuilder
pub fn builder() -> UpdateDataCatalogInputBuilder
Creates a new builder-style object to manufacture UpdateDataCatalogInput.